@@ -18,17 +18,22 @@ try:
 except ImportError:
 	hildon = None
 
+print 'hildon'
+print hildon
+
 class mTasks(object):
 
 	__pretty_app_name__ = "mTasks"
-	__app_name__ = "mtasks"
-	__version__ = "0.2.1"
+	__app_name__ = "mTasks"
+	__version__ = "0.2.2"
+	__context__ = "net.khertan.mtasks"
 
 	_glade_files = [
-		'ui/mtasks.glade',
+		'/usr/lib/mtasks/ui/mtasks.glade',
 	]
 
-	def __init__(self):
+	def __init__(self,app,context):
+		print 'start init'
 		self._callbackList = None
 
 		for path in mTasks._glade_files:
@@ -50,7 +55,8 @@ class mTasks(object):
 			warnings.warn("Hildon installed but glade file not updated to work with hildon", UserWarning, 2)
 			hildon = None
 		elif hildon is not None:
-			self._app = hildon.Program()
+			self._app = app
+			self._context = context
 			self._window = hildon.Window()
 			self._window.set_border_width(0)
 			self._widgetTree.get_widget("VirtualWindow").reparent(self._window)
@@ -60,6 +66,8 @@ class mTasks(object):
 			self._window.connect("window-state-event", self._on_window_state_change)
 		else:
 			warnings.warn("No Hildon", UserWarning, 2)
+			
+		print '1'
 
 		if hildon is not None:
 			self._window.set_title("mTasks")
@@ -75,13 +83,17 @@ class mTasks(object):
 		  "on_bNew_clicked": self._add_task,
 		}
 		self._widgetTree.signal_autoconnect(callbackMapping)
+		
+		print '2'
 
 		if self._window:
 			self._children_color_bg(self._window)
 			self._window.connect("delete-event", self._win_closebox)
 			self._window.show()
+		print '3'
 
 		threading.Thread(target=self._idle_setup).start()
+		print 'inited'
 
 	def _delete_task(self,widget):
 		selection = self.tasksListTree.get_selection()
@@ -95,6 +107,7 @@ class mTasks(object):
 
 	def refresh(self):
 #		gtk.gdk.threads_enter()
+		print 'start refresh'
 		tasks_list =  mtasks_framework.TasksList().get_all_tasks()
 		tasks_list.sort()
 		new_order = range(len(tasks_list))
@@ -111,13 +124,13 @@ class mTasks(object):
 		self._tasksList.reorder(new_order)
 #		gtk.gdk.threads_leave()
 		self._pijama_color()
+		print 'end refresh'
 
 	def _pijama_color(self):
 		#pijama
 #		gtk.gdk.threads_enter()
 		iter = self._tasksList.get_iter_root()
 		pij = True
-		print 'pjama'
 		while(iter):
 			if pij == True:
 				color = '#E5E5FF'
@@ -128,7 +141,6 @@ class mTasks(object):
 			iter = self._tasksList.iter_next(iter)
 		self.tasksListTree.queue_draw()
 #		gtk.gdk.threads_leave()
-		print 'end pjama'
 
 	def _set_low(self,widget):
 		selection = self.tasksListTree.get_selection()
@@ -192,6 +204,7 @@ class mTasks(object):
 		"""
 		If something can be done after the UI loads, push it here so it's not blocking the UI
 		"""
+		gtk.gdk.threads_enter()
 
 		try:
 			import osso
@@ -204,7 +217,7 @@ class mTasks(object):
 		else:
 			warnings.warn("No OSSO", UserWarning, 2)
 
-		gtk.gdk.threads_enter()
+		
 		self._tasksList = self._tasksList = gtk.ListStore(gobject.TYPE_STRING, gobject.TYPE_BOOLEAN, gobject.TYPE_STRING, gobject.TYPE_INT,gobject.TYPE_STRING,gobject.TYPE_STRING,gobject.TYPE_STRING,gobject.TYPE_INT)
 		self.tasksListTree = self._widgetTree.get_widget("tDisplay")
 		self.tasksListTree.set_rubber_banding(True)
@@ -263,6 +276,8 @@ class mTasks(object):
 		gtk.gdk.threads_enter()
 		self.create_menu()
 		gtk.gdk.threads_leave()
+		
+		print 'end idle'
 
 		return False
 
@@ -279,10 +294,12 @@ class mTasks(object):
 		tasksList.append((uuid,status==1,datetime, priority,description, fg_color,bg_color,style))
 
 	def _load_taskslist_bg(self):
+		gtk.gdk.threads_enter()
 		self._tasksList = gtk.ListStore(gobject.TYPE_STRING, gobject.TYPE_BOOLEAN, gobject.TYPE_STRING, gobject.TYPE_INT,gobject.TYPE_STRING,gobject.TYPE_STRING,gobject.TYPE_STRING,gobject.TYPE_INT)
 		self.tasksListTree.set_model(self._tasksList)
 		self._tasks_loader_process = threading.Thread(target=self._load_taskslist,args=[self._tasksList])
 		self._tasks_loader_process.start()
+		gtk.gdk.threads_leave()
 
 	def _load_taskslist(self,tasksList):
 		gtk.gdk.threads_enter()
@@ -333,7 +350,7 @@ class mTasks(object):
 			task.save_to_db()
 			self.refresh()
 			return
-			
+
 	def purge_done(self,widget,*data):
 		mtasks_framework
 		tasks_uuid_list =  mtasks_framework.TasksList().get_done_tasks()
@@ -390,11 +407,11 @@ class mTasks(object):
 		dialog.connect ("response", lambda d, r: d.destroy())
 		dialog.show()
 
-def run_mtasks():
+def run_mtasks(app,context):
 	gtk.gdk.threads_init()
 	if hildon is not None:
 		gtk.set_application_name(mTasks.__pretty_app_name__)
-	handle = mTasks()
+	handle = mTasks(app,context)
 	gtk.main()
 
 if __name__ == "__main__":
